---
tags: [gradio-custom-component, ]
title: gradio_mcp_tools_visualizer
short_description: A gradio custom component
colorFrom: blue
colorTo: yellow
sdk: gradio
pinned: false
app_file: space.py
---

# gradio_mcp_tools_visualizer

You can auto-generate documentation for your custom component with the `gradio cc docs` command.
You can also edit this file however you like.
